@@ -39,8 +39,6 @@ static bool subimages     = false;
 static bool compute_sha1  = false;
 static bool compute_stats = false;
 
-using OIIO::print;
-
 
 
 static void
@@ -48,7 +46,7 @@ print_sha1(ImageInput* input, int subimage, int miplevel)
 {
     std::string err;
     std::string s1 = pvt::compute_sha1(input, subimage, miplevel, err);
-    print("    SHA-1: {}\n", err.size() ? err : s1);
+    OIIO::print("    SHA-1: {}\n", err.size() ? err : s1);
 }
 
 
@@ -84,7 +82,7 @@ print_stats(const std::string& filename, const ImageSpec& originalspec,
 
     std::string err;
     if (!pvt::print_stats(std::cout, indent, input, originalspec, ROI(), err)) {
-        print("{}Stats: (unable to compute)\n", indent);
+        OIIO::print("{}Stats: (unable to compute)\n", indent);
         if (err.size())
             std::cerr << "Error: " << err << "\n";
         return;
@@ -100,30 +98,30 @@ print_metadata(const ImageSpec& spec, const std::string& filename)
     if (metamatch.empty() || std::regex_search("channels", field_re)
         || std::regex_search("channel list", field_re)) {
         if (filenameprefix)
-            print("{} : ", filename);
-        print("    channel list: ");
+            OIIO::print("{} : ", filename);
+        OIIO::print("    channel list: ");
         for (int i = 0; i < spec.nchannels; ++i) {
             if (i < (int)spec.channelnames.size())
-                print("{}", spec.channelnames[i]);
+                OIIO::print("{}", spec.channelnames[i]);
             else
-                print("unknown");
+                OIIO::print("unknown");
             if (i < (int)spec.channelformats.size())
-                print(" ({})", spec.channelformats[i]);
+                OIIO::print(" ({})", spec.channelformats[i]);
             if (i < spec.nchannels - 1)
-                print(", ");
+                OIIO::print(", ");
         }
-        print("\n");
+        OIIO::print("\n");
         printed = true;
     }
     if (spec.x || spec.y || spec.z) {
         if (metamatch.empty()
             || std::regex_search("pixel data origin", field_re)) {
             if (filenameprefix)
-                print("{} : ", filename);
-            print("    pixel data origin: x={}, y={}", spec.x, spec.y);
+                OIIO::print("{} : ", filename);
+            OIIO::print("    pixel data origin: x={}, y={}", spec.x, spec.y);
             if (spec.depth > 1)
-                print(", z={}", spec.z);
-            print("\n");
+                OIIO::print(", z={}", spec.z);
+            OIIO::print("\n");
             printed = true;
         }
     }
@@ -134,33 +132,35 @@ print_metadata(const ImageSpec& spec, const std::string& filename)
         if (metamatch.empty()
             || std::regex_search("full/display size", field_re)) {
             if (filenameprefix)
-                print("{} : ", filename);
-            print("    full/display size: {} x {}", spec.full_width,
-                  spec.full_height);
+                OIIO::print("{} : ", filename);
+            OIIO::print("    full/display size: {} x {}", spec.full_width,
+                        spec.full_height);
             if (spec.depth > 1)
-                print(" x {}", spec.full_depth);
-            print("\n");
+                OIIO::print(" x {}", spec.full_depth);
+            OIIO::print("\n");
             printed = true;
         }
         if (metamatch.empty()
             || std::regex_search("full/display origin", field_re)) {
             if (filenameprefix)
-                print("{} : ", filename);
-            print("    full/display origin: {}, {}", spec.full_x, spec.full_y);
+                OIIO::print("{} : ", filename);
+            OIIO::print("    full/display origin: {}, {}", spec.full_x,
+                        spec.full_y);
             if (spec.depth > 1)
-                print(", {}", spec.full_z);
-            print("\n");
+                OIIO::print(", {}", spec.full_z);
+            OIIO::print("\n");
             printed = true;
         }
     }
     if (spec.tile_width) {
         if (metamatch.empty() || std::regex_search("tile", field_re)) {
             if (filenameprefix)
-                print("{} : ", filename);
-            print("    tile size: {} x {}", spec.tile_width, spec.tile_height);
+                OIIO::print("{} : ", filename);
+            OIIO::print("    tile size: {} x {}", spec.tile_width,
+                        spec.tile_height);
             if (spec.depth > 1)
-                print(" x {}", spec.tile_depth);
-            print("\n");
+                OIIO::print(" x {}", spec.tile_depth);
+            OIIO::print("\n");
             printed = true;
         }
     }
@@ -176,20 +176,20 @@ print_metadata(const ImageSpec& spec, const std::string& filename)
             continue;
         std::string s = spec.metadata_val(p, true);
         if (filenameprefix)
-            print("{} : ", filename);
-        print("    {}: ", p.name());
+            OIIO::print("{} : ", filename);
+        OIIO::print("    {}: ", p.name());
         if (s == "1.#INF")
-            print("inf");
+            OIIO::print("inf");
         else
-            print("{}", s);
-        print("\n");
+            OIIO::print("{}", s);
+        OIIO::print("\n");
         printed = true;
     }
 
     if (!printed && !metamatch.empty()) {
         if (filenameprefix)
-            print("{} : ", filename);
-        print("    {}: <unknown>\n", metamatch);
+            OIIO::print("{} : ", filename);
+        OIIO::print("    {}: <unknown>\n", metamatch);
     }
 }
 
@@ -260,34 +260,35 @@ print_info_subimage(int current_subimage, int max_subimages, ImageSpec& spec,
               || std::regex_search("resolution, width, height, depth, channels",
                                    field_re));
     if (printres && max_subimages > 1 && subimages) {
-        print(" subimage {:2}: ", current_subimage);
-        print("{:4} x {:4}", spec.width, spec.height);
+        OIIO::print(" subimage {:2}: ", current_subimage);
+        OIIO::print("{:4} x {:4}", spec.width, spec.height);
         if (spec.depth > 1)
-            print(" x {:4}", spec.depth);
+            OIIO::print(" x {:4}", spec.depth);
         int bits = spec.get_int_attribute("oiio:BitsPerSample", 0);
-        print(", {} channel, {}{}{}", spec.nchannels, spec.deep ? "deep " : "",
-              spec.depth > 1 ? "volume " : "",
-              extended_format_name(spec.format, bits));
-        print(" {}", input->format_name());
-        print("\n");
+        OIIO::print(", {} channel, {}{}{}", spec.nchannels,
+                    spec.deep ? "deep " : "", spec.depth > 1 ? "volume " : "",
+                    extended_format_name(spec.format, bits));
+        OIIO::print(" {}", input->format_name());
+        OIIO::print("\n");
     }
     // Count MIP levels
     while (input->seek_subimage(current_subimage, nmip)) {
         if (printres) {
             ImageSpec mipspec = input->spec_dimensions(current_subimage, nmip);
             if (nmip == 1)
-                print("    MIP-map levels: {}x{}", spec.width, spec.height);
-            print(" {}x{}", mipspec.width, mipspec.height);
+                OIIO::print("    MIP-map levels: {}x{}", spec.width,
+                            spec.height);
+            OIIO::print(" {}x{}", mipspec.width, mipspec.height);
         }
         ++nmip;
     }
     if (printres && nmip > 1)
-        print("\n");
+        OIIO::print("\n");
 
     if (compute_sha1
         && (metamatch.empty() || std::regex_search("sha-1", field_re))) {
         if (filenameprefix)
-            print("{} : ", filename);
+            OIIO::print("{} : ", filename);
         // Before sha-1, be sure to point back to the highest-res MIP level
         input->seek_subimage(current_subimage, 0);
         print_sha1(input, current_subimage, 0);
@@ -301,10 +302,10 @@ print_info_subimage(int current_subimage, int max_subimages, ImageSpec& spec,
         for (int m = 0; m < nmip; ++m) {
             ImageSpec mipspec = input->spec_dimensions(current_subimage, m);
             if (filenameprefix)
-                print("{} : ", filename);
+                OIIO::print("{} : ", filename);
             if (nmip > 1 && (subimages || m == 0)) {
-                print("    MIP {} of {} ({} x {}):\n", m, nmip, mipspec.width,
-                      mipspec.height);
+                OIIO::print("    MIP {} of {} ({} x {}):\n", m, nmip,
+                            mipspec.width, mipspec.height);
             }
             print_stats(filename, spec, current_subimage, m, nmip > 1);
         }
@@ -352,57 +353,58 @@ print_info(const std::string& filename, size_t namefieldlength,
     if (metamatch.empty()
         || std::regex_search("resolution, width, height, depth, channels",
                              field_re)) {
-        print("{}{} : {:4} x {:4}", filename, padding, spec.width, spec.height);
+        OIIO::print("{}{} : {:4} x {:4}", filename, padding, spec.width,
+                    spec.height);
         if (spec.depth > 1)
-            print(" x {:4}", spec.depth);
-        print(", {} channel, {}{}", spec.nchannels, spec.deep ? "deep " : "",
-              spec.depth > 1 ? "volume " : "");
+            OIIO::print(" x {:4}", spec.depth);
+        OIIO::print(", {} channel, {}{}", spec.nchannels,
+                    spec.deep ? "deep " : "", spec.depth > 1 ? "volume " : "");
         if (spec.channelformats.size()) {
             for (size_t c = 0; c < spec.channelformats.size(); ++c)
-                print("{}{}", c ? "/" : "", spec.channelformat(c));
+                OIIO::print("{}{}", c ? "/" : "", spec.channelformat(c));
         } else {
             int bits = spec.get_int_attribute("oiio:BitsPerSample", 0);
-            print("{}", extended_format_name(spec.format, bits));
+            OIIO::print("{}", extended_format_name(spec.format, bits));
         }
-        print(" {}", input->format_name());
+        OIIO::print(" {}", input->format_name());
         if (sum) {
             imagesize_t imagebytes = spec.image_bytes(true);
             totalsize += imagebytes;
-            print(" ({:.2f} MB)", (float)imagebytes / (1024.0 * 1024.0));
+            OIIO::print(" ({:.2f} MB)", (float)imagebytes / (1024.0 * 1024.0));
         }
         // we print info about how many subimages are stored in file
         // only when we have more then one subimage
         if (!verbose && num_of_subimages != 1)
-            print(" ({} subimages{})", num_of_subimages,
-                  any_mipmapping ? " +mipmap)" : "");
+            OIIO::print(" ({} subimages{})", num_of_subimages,
+                        any_mipmapping ? " +mipmap)" : "");
         if (!verbose && num_of_subimages == 1 && any_mipmapping)
-            print(" (+mipmap)");
-        print("\n");
+            OIIO::print(" (+mipmap)");
+        OIIO::print("\n");
     }
 
     int movie = spec.get_int_attribute("oiio:Movie");
     if (verbose && num_of_subimages != 1) {
         // info about num of subimages and their resolutions
-        print("    {} subimages: ", num_of_subimages);
+        OIIO::print("    {} subimages: ", num_of_subimages);
         for (int i = 0; i < num_of_subimages; ++i) {
             spec     = input->spec(i, 0);
             int bits = spec.get_int_attribute("oiio:BitsPerSample",
                                               spec.format.size() * 8);
             if (i)
-                print(", ");
+                OIIO::print(", ");
             if (spec.depth > 1)
-                print("{}x{}x{} ", spec.width, spec.height, spec.depth);
+                OIIO::print("{}x{}x{} ", spec.width, spec.height, spec.depth);
             else
-                print("{}x{} ", spec.width, spec.height);
-            // print("[");
+                OIIO::print("{}x{} ", spec.width, spec.height);
+            // OIIO::print("[");
             for (int c = 0; c < spec.nchannels; ++c)
-                print("{:c}{}", c ? ',' : '[',
-                      brief_format_name(spec.channelformat(c), bits));
-            print("]");
+                OIIO::print("{:c}{}", c ? ',' : '[',
+                            brief_format_name(spec.channelformat(c), bits));
+            OIIO::print("]");
             if (movie)
                 break;
         }
-        print("\n");
+        OIIO::print("\n");
     }
 
     // if the '-a' flag is not set we print info
@@ -472,8 +474,8 @@ main(int argc, const char* argv[])
         auto in = ImageInput::open(s);
         if (!in) {
             std::string err = geterror();
-            print(std::cerr, "iinfo ERROR: \"{}\" : {}\n", s,
-                  err.size() ? err : std::string("Could not open file."));
+            OIIO::print(std::cerr, "iinfo ERROR: \"{}\" : {}\n", s,
+                        err.size() ? err : std::string("Could not open file."));
             returncode = EXIT_FAILURE;
             continue;
         }
@@ -482,7 +484,7 @@ main(int argc, const char* argv[])
     }
 
     if (sum)
-        print("Total size: {}\n", Strutil::memformat(totalsize));
+        OIIO::print("Total size: {}\n", Strutil::memformat(totalsize));
 
     shutdown();
     return returncode;
